@@ -3,7 +3,9 @@ build_time_vars = {'ABIFLAGS': 'd',
  'AC_APPLE_UNIVERSAL_BUILD': 0,
  'AIX_BUILDDATE': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
- 'ALT_SOABI': '"cpython-39-arm-linux-gnueabihf"',
+ 'ALIGNOF_LONG': 4,
+ 'ALIGNOF_SIZE_T': 4,
+ 'ALT_SOABI': '"cpython-310-arm-linux-gnueabihf"',
  'ANDROID_API_LEVEL': 0,
  'AR': 'ar',
  'ARFLAGS': 'rcs',
@@ -11,15 +13,15 @@ build_time_vars = {'ABIFLAGS': 'd',
  'BASECPPFLAGS': '-IObjects -IInclude -IPython',
  'BASEMODLIBS': '',
  'BINDIR': '/usr/bin',
- 'BINLIBDEST': '/usr/lib/python3.9',
- 'BLDLIBRARY': '-L. -lpython3.9d',
- 'BLDSHARED': 'gcc -pthread -shared -Wl,-z,relro -Wl,--as-needed  -Wl,-z,now   '
-              '-g  -Wl,-z,relro -Wl,--as-needed  -Wl,-z,now   -g',
+ 'BINLIBDEST': '/usr/lib/python3.10',
+ 'BLDLIBRARY': '-L. -lpython3.10d',
+ 'BLDSHARED': 'gcc -shared -Wl,-z,relro -Wl,--as-needed  -Wl,-z,now    -g  '
+              '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now    -g',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
  'BUILD_GNU_TYPE': 'armv7hl-redhat-linux-gnu',
  'BYTESTR_DEPS': '\\',
- 'CC': 'gcc -pthread',
+ 'CC': 'gcc',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DDYNAMIC_ANNOTATIONS_ENABLED=1  '
            '-O2  -fexceptions -g -grecord-gcc-switches -pipe -Wall '
@@ -53,24 +55,21 @@ build_time_vars = {'ABIFLAGS': 'd',
                             '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                             '-Wp,-D_GLIBCXX_ASSERTIONS '
                             '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
-                            '-fstack-protector-strong '
-                            '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
-                            '-march=armv7-a -mfpu=vfpv3-d16 '
-                            '-mtune=generic-armv7-a -mabi=aapcs-linux '
-                            '-mfloat-abi=hard -D_GNU_SOURCE -fPIC -fwrapv '
-                            '-fno-semantic-interposition -flto '
-                            '-fuse-linker-plugin -ffat-lto-objects '
-                            '-flto-partition=none -g -std=c99 -Wextra '
-                            '-Wno-unused-result -Wno-unused-parameter '
+                            '-fstack-protector-strong   -march=armv7-a '
+                            '-mfpu=vfpv3-d16 -mtune=generic-armv7-a '
+                            '-mabi=aapcs-linux -mfloat-abi=hard -D_GNU_SOURCE '
+                            '-fPIC -fwrapv -flto -fuse-linker-plugin '
+                            '-ffat-lto-objects -flto-partition=none -g '
+                            '-std=c99 -Wextra -Wno-unused-result '
+                            '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '',
- 'CONFIGURE_LDFLAGS': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now   -g',
+ 'CONFIGURE_LDFLAGS': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now    -g',
  'CONFIGURE_LDFLAGS_NODIST': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now '
-                             '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld  '
-                             '-fno-semantic-interposition -g  -flto '
-                             '-fuse-linker-plugin -ffat-lto-objects '
+                             '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld   '
+                             '-g  -flto -fuse-linker-plugin -ffat-lto-objects '
                              '-flto-partition=none -g',
  'CONFIG_ARGS': "'--build=armv7hl-redhat-linux-gnu' "
                 "'--host=armv7hl-redhat-linux-gnu' '--program-prefix=' "
@@ -84,10 +83,12 @@ build_time_vars = {'ABIFLAGS': 'd',
                 "'--with-platlibdir=lib' '--enable-ipv6' '--enable-shared' "
                 "'--with-computed-gotos=yes' "
                 "'--with-dbmliborder=gdbm:ndbm:bdb' '--with-system-expat' "
-                "'--with-system-ffi' '--enable-loadable-sqlite-extensions' "
-                "'--with-dtrace' '--with-lto' "
-                "'--with-ssl-default-suites=openssl' '--with-valgrind' "
-                "'--without-ensurepip' '--with-pydebug' "
+                "'--with-system-ffi' '--with-system-libmpdec' "
+                "'--enable-loadable-sqlite-extensions' '--with-dtrace' "
+                "'--with-lto' '--with-ssl-default-suites=openssl' "
+                "'--without-static-libpython' "
+                "'--with-wheel-pkg-dir=/usr/share/python-wheels' "
+                "'--with-valgrind' '--without-ensurepip' '--with-pydebug' "
                 "'build_alias=armv7hl-redhat-linux-gnu' "
                 "'host_alias=armv7hl-redhat-linux-gnu' 'CC=gcc' 'CFLAGS= -O2  "
                 '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
@@ -96,22 +97,22 @@ build_time_vars = {'ABIFLAGS': 'd',
                 '-march=armv7-a -mfpu=vfpv3-d16 -mtune=generic-armv7-a '
                 '-mabi=aapcs-linux -mfloat-abi=hard -D_GNU_SOURCE -fPIC '
                 "-fwrapv ' 'LDFLAGS= -Wl,-z,relro -Wl,--as-needed  "
-                "-Wl,-z,now   -g ' 'CPPFLAGS=' "
-                "'PKG_CONFIG_PATH=:/usr/lib/pkgconfig:/usr/share/pkgconfig'",
+                "-Wl,-z,now    -g ' 'CPPFLAGS='",
  'CONFINCLUDEDIR': '/usr/include',
- 'CONFINCLUDEPY': '/usr/include/python3.9d',
+ 'CONFINCLUDEPY': '/usr/include/python3.10d',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/builddir/build/BUILD/Python-3.9.2/build/debug/coverage.info',
- 'COVERAGE_REPORT': '/builddir/build/BUILD/Python-3.9.2/build/debug/lcov-report',
+ 'COVERAGE_INFO': '/builddir/build/BUILD/Python-3.10.0/build/debug/coverage.info',
+ 'COVERAGE_REPORT': '/builddir/build/BUILD/Python-3.10.0/build/debug/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-             '-I/builddir/build/BUILD/Python-3.9.2/Include',
- 'CXX': 'g++ -pthread',
- 'DESTDIRS': '/usr /usr/lib /usr/lib/python3.9 /usr/lib/python3.9/lib-dynload',
- 'DESTLIB': '/usr/lib/python3.9',
+             '-I/builddir/build/BUILD/Python-3.10.0/Include',
+ 'CXX': 'g++',
+ 'DESTDIRS': '/usr /usr/lib /usr/lib/python3.10 '
+             '/usr/lib/python3.10/lib-dynload',
+ 'DESTLIB': '/usr/lib/python3.10',
  'DESTPATH': '',
- 'DESTSHARED': '/usr/lib/python3.9/lib-dynload',
+ 'DESTSHARED': '/usr/lib/python3.10/lib-dynload',
  'DFLAGS': '',
  'DIRMODE': 755,
  'DIST': 'README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
@@ -133,10 +134,11 @@ build_time_vars = {'ABIFLAGS': 'd',
  'ENSUREPIP': 'no',
  'EXE': '',
  'EXEMODE': 755,
+ 'EXPERIMENTAL_ISOLATED_SUBINTERPRETERS': 0,
  'EXPORTSFROM': '',
  'EXPORTSYMS': '',
  'EXTRATESTOPTS': '',
- 'EXT_SUFFIX': '.cpython-39d-arm-linux-gnueabihf.so',
+ 'EXT_SUFFIX': '.cpython-310d-arm-linux-gnueabihf.so',
  'FILEMODE': 644,
  'FLOAT_WORDS_BIGENDIAN': 0,
  'FLOCK_NEEDS_LIBBSD': 0,
@@ -174,6 +176,7 @@ build_time_vars = {'ABIFLAGS': 'd',
  'HAVE_CLOCK_GETRES': 1,
  'HAVE_CLOCK_GETTIME': 1,
  'HAVE_CLOCK_SETTIME': 1,
+ 'HAVE_CLOSE_RANGE': 1,
  'HAVE_COMPUTED_GOTOS': 1,
  'HAVE_CONFSTR': 1,
  'HAVE_CONIO_H': 0,
@@ -226,6 +229,7 @@ build_time_vars = {'ABIFLAGS': 'd',
  'HAVE_ERF': 1,
  'HAVE_ERFC': 1,
  'HAVE_ERRNO_H': 1,
+ 'HAVE_EVENTFD': 1,
  'HAVE_EXECV': 1,
  'HAVE_EXPLICIT_BZERO': 1,
  'HAVE_EXPLICIT_MEMSET': 0,
@@ -367,6 +371,7 @@ build_time_vars = {'ABIFLAGS': 'd',
  'HAVE_NETPACKET_PACKET_H': 1,
  'HAVE_NET_IF_H': 1,
  'HAVE_NICE': 1,
+ 'HAVE_NON_UNICODE_WCHAR_T_REPRESENTATION': 0,
  'HAVE_OPENAT': 1,
  'HAVE_OPENPTY': 1,
  'HAVE_PATHCONF': 1,
@@ -459,6 +464,7 @@ build_time_vars = {'ABIFLAGS': 'd',
  'HAVE_SOCKADDR_STORAGE': 1,
  'HAVE_SOCKETPAIR': 1,
  'HAVE_SPAWN_H': 1,
+ 'HAVE_SPLICE': 1,
  'HAVE_SSIZE_T': 1,
  'HAVE_STATVFS': 1,
  'HAVE_STAT_TV_NSEC': 1,
@@ -467,7 +473,6 @@ build_time_vars = {'ABIFLAGS': 'd',
  'HAVE_STDINT_H': 1,
  'HAVE_STDLIB_H': 1,
  'HAVE_STD_ATOMIC': 1,
- 'HAVE_STRDUP': 1,
  'HAVE_STRFTIME': 1,
  'HAVE_STRINGS_H': 1,
  'HAVE_STRING_H': 1,
@@ -494,6 +499,7 @@ build_time_vars = {'ABIFLAGS': 'd',
  'HAVE_SYS_DIR_H': 0,
  'HAVE_SYS_ENDIAN_H': 0,
  'HAVE_SYS_EPOLL_H': 1,
+ 'HAVE_SYS_EVENTFD_H': 1,
  'HAVE_SYS_EVENT_H': 0,
  'HAVE_SYS_FILE_H': 1,
  'HAVE_SYS_IOCTL_H': 1,
@@ -554,6 +560,7 @@ build_time_vars = {'ABIFLAGS': 'd',
  'HAVE_UUID_GENERATE_TIME_SAFE': 1,
  'HAVE_UUID_H': 0,
  'HAVE_UUID_UUID_H': 1,
+ 'HAVE_VFORK': 1,
  'HAVE_WAIT3': 1,
  'HAVE_WAIT4': 1,
  'HAVE_WAITID': 1,
@@ -565,48 +572,49 @@ build_time_vars = {'ABIFLAGS': 'd',
  'HAVE_WMEMCMP': 1,
  'HAVE_WORKING_TZSET': 1,
  'HAVE_WRITEV': 1,
- 'HAVE_X509_VERIFY_PARAM_SET1_HOST': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
  'HOST_GNU_TYPE': 'armv7hl-redhat-linux-gnu',
- 'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python3.9d '
-                   '/usr/include/python3.9d',
+ 'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python3.10d '
+                   '/usr/include/python3.10d',
  'INCLUDEDIR': '/usr/include',
- 'INCLUDEPY': '/usr/include/python3.9d',
+ 'INCLUDEPY': '/usr/include/python3.10d',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': '/usr/bin/install -c -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c',
  'INSTALL_SCRIPT': '/usr/bin/install -c',
  'INSTALL_SHARED': '/usr/bin/install -c -m 755',
- 'INSTSONAME': 'libpython3.9d.so.1.0',
+ 'INSTSONAME': 'libpython3.10d.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
- 'LDCXXSHARED': 'g++ -pthread -shared',
- 'LDFLAGS': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now   -g  -Wl,-z,relro '
-            '-Wl,--as-needed  -Wl,-z,now   -g',
- 'LDLIBRARY': 'libpython3.9d.so',
+ 'LDCXXSHARED': 'g++ -shared',
+ 'LDFLAGS': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now    -g  -Wl,-z,relro '
+            '-Wl,--as-needed  -Wl,-z,now    -g',
+ 'LDLIBRARY': 'libpython3.10d.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'gcc -pthread -shared -Wl,-z,relro -Wl,--as-needed  -Wl,-z,now   '
-             '-g  -Wl,-z,relro -Wl,--as-needed  -Wl,-z,now   -g',
- 'LDVERSION': '3.9d',
+ 'LDSHARED': 'gcc -shared -Wl,-z,relro -Wl,--as-needed  -Wl,-z,now    -g  '
+             '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now    -g',
+ 'LDVERSION': '3.10d',
  'LIBC': '',
- 'LIBDEST': '/usr/lib/python3.9',
+ 'LIBDEST': '/usr/lib/python3.10',
  'LIBDIR': '/usr/lib',
  'LIBFFI_INCLUDEDIR': '',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
  'LIBPC': '/usr/lib/pkgconfig',
- 'LIBPL': '/usr/lib/python3.9/config-3.9d-arm-linux-gnueabihf',
+ 'LIBPL': '/usr/lib/python3.10/config-3.10d-arm-linux-gnueabihf',
  'LIBPYTHON': '',
- 'LIBRARY': 'libpython3.9d.a',
+ 'LIBRARY': 'libpython3.10d.a',
+ 'LIBRARY_DEPS': 'libpython3.10d.so',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
- 'LIBS': '-lcrypt -lpthread -ldl  -lutil -lm',
- 'LIBSUBDIRS': 'tkinter tkinter/test tkinter/test/test_tkinter \\',
+ 'LIBS': '-lcrypt -ldl  -lm',
+ 'LIBSUBDIRS': 'asyncio \\',
  'LINKCC': 'gcc',
  'LINKFORSHARED': '-Xlinker -export-dynamic',
  'LIPO_32BIT_FLAGS': '',
+ 'LIPO_INTEL64_FLAGS': '',
  'LLVM_PROF_ERR': 'no',
  'LLVM_PROF_FILE': '',
  'LLVM_PROF_MERGER': 'true',
@@ -614,18 +622,18 @@ build_time_vars = {'ABIFLAGS': 'd',
  'LOCALMODLIBS': '',
  'MACHDEP': 'linux',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/usr/lib/python3.9',
+ 'MACHDESTLIB': '/usr/lib/python3.10',
  'MACOSX_DEPLOYMENT_TARGET': '',
- 'MAINCC': 'gcc -pthread',
+ 'MAINCC': 'gcc',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 1,
- 'MAKESETUP': '/builddir/build/BUILD/Python-3.9.2/Modules/makesetup',
+ 'MAKESETUP': '/builddir/build/BUILD/Python-3.10.0/Modules/makesetup',
  'MANDIR': '/usr/share/man',
  'MKDIR_P': '/usr/bin/mkdir -p',
  'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
                    '_operator  _collections  _abc  itertools  atexit  _signal  '
                    '_stat  time  _thread  _locale  _io  faulthandler  '
-                   '_tracemalloc  _peg_parser  _symtable  xxsubtype',
+                   '_tracemalloc  _symtable  xxsubtype',
  'MODDISABLED_NAMES': '',
  'MODLIBS': '',
  'MODOBJS': 'Modules/posixmodule.o  Modules/errnomodule.o  '
@@ -638,8 +646,8 @@ build_time_vars = {'ABIFLAGS': 'd',
             'Modules/_localemodule.o  Modules/_iomodule.o Modules/iobase.o '
             'Modules/fileio.o Modules/bytesio.o Modules/bufferedio.o '
             'Modules/textio.o Modules/stringio.o  Modules/faulthandler.o  '
-            'Modules/_tracemalloc.o  Modules/_peg_parser.o  '
-            'Modules/symtablemodule.o  Modules/xxsubtype.o',
+            'Modules/_tracemalloc.o  Modules/symtablemodule.o  '
+            'Modules/xxsubtype.o',
  'MODULE_OBJS': '\\',
  'MULTIARCH': 'arm-linux-gnueabihf',
  'MULTIARCH_CPPFLAGS': '-DMULTIARCH=\\"arm-linux-gnueabihf\\"',
@@ -649,6 +657,7 @@ build_time_vars = {'ABIFLAGS': 'd',
  'OPENSSL_INCLUDES': '',
  'OPENSSL_LDFLAGS': '',
  'OPENSSL_LIBS': '-lssl -lcrypto',
+ 'OPENSSL_RPATH': '',
  'OPT': '-DDYNAMIC_ANNOTATIONS_ENABLED=1  -O2  -fexceptions -g '
         '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
         '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
@@ -663,8 +672,7 @@ build_time_vars = {'ABIFLAGS': 'd',
  'PACKAGE_URL': 0,
  'PACKAGE_VERSION': 0,
  'PARSER_HEADERS': '\\',
- 'PARSER_OBJS': '\\ \\ Parser/myreadline.o Parser/parsetok.o '
-                'Parser/tokenizer.o',
+ 'PARSER_OBJS': '\\ \\ Parser/myreadline.o Parser/tokenizer.o',
  'PEGEN_HEADERS': '\\',
  'PEGEN_OBJS': '\\',
  'PGO_PROF_GEN_FLAG': '-fprofile-generate',
@@ -672,7 +680,7 @@ build_time_vars = {'ABIFLAGS': 'd',
  'PLATLIBDIR': 'lib',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
- 'PROFILE_TASK': '-m test --pgo',
+ 'PROFILE_TASK': '-m test --pgo --timeout=1200',
  'PTHREAD_KEY_T_IS_COMPATIBLE_WITH_INT': 1,
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PY3LIBRARY': '',
@@ -684,6 +692,7 @@ build_time_vars = {'ABIFLAGS': 'd',
  'PYTHONFRAMEWORKPREFIX': '',
  'PYTHONPATH': '',
  'PYTHON_FOR_BUILD': './python -E',
+ 'PYTHON_FOR_REGEN': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
@@ -716,15 +725,13 @@ build_time_vars = {'ABIFLAGS': 'd',
                              '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wp,-D_GLIBCXX_ASSERTIONS '
                              '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
-                             '-fstack-protector-strong '
-                             '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
-                             '-march=armv7-a -mfpu=vfpv3-d16 '
-                             '-mtune=generic-armv7-a -mabi=aapcs-linux '
-                             '-mfloat-abi=hard -D_GNU_SOURCE -fPIC -fwrapv '
-                             '-fno-semantic-interposition -flto '
-                             '-fuse-linker-plugin -ffat-lto-objects '
-                             '-flto-partition=none -g -std=c99 -Wextra '
-                             '-Wno-unused-result -Wno-unused-parameter '
+                             '-fstack-protector-strong   -march=armv7-a '
+                             '-mfpu=vfpv3-d16 -mtune=generic-armv7-a '
+                             '-mabi=aapcs-linux -mfloat-abi=hard -D_GNU_SOURCE '
+                             '-fPIC -fwrapv -flto -fuse-linker-plugin '
+                             '-ffat-lto-objects -flto-partition=none -g '
+                             '-std=c99 -Wextra -Wno-unused-result '
+                             '-Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden -O2 -flto=auto '
@@ -733,15 +740,13 @@ build_time_vars = {'ABIFLAGS': 'd',
                              '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wp,-D_GLIBCXX_ASSERTIONS '
                              '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
-                             '-fstack-protector-strong '
-                             '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
-                             '-march=armv7-a -mfpu=vfpv3-d16 '
-                             '-mtune=generic-armv7-a -mabi=aapcs-linux '
-                             '-mfloat-abi=hard -D_GNU_SOURCE -fPIC -fwrapv '
-                             '-fno-semantic-interposition -O0 -Wno-cpp '
-                             '-I/builddir/build/BUILD/Python-3.9.2/Include/internal '
+                             '-fstack-protector-strong   -march=armv7-a '
+                             '-mfpu=vfpv3-d16 -mtune=generic-armv7-a '
+                             '-mabi=aapcs-linux -mfloat-abi=hard -D_GNU_SOURCE '
+                             '-fPIC -fwrapv -O0 -Wno-cpp '
+                             '-I/builddir/build/BUILD/Python-3.10.0/Include/internal '
                              '-IObjects -IInclude -IPython -I. '
-                             '-I/builddir/build/BUILD/Python-3.9.2/Include '
+                             '-I/builddir/build/BUILD/Python-3.10.0/Include '
                              '-fPIC -DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare '
               '-DDYNAMIC_ANNOTATIONS_ENABLED=1  -O2  -fexceptions -g '
@@ -765,11 +770,9 @@ build_time_vars = {'ABIFLAGS': 'd',
                      '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                      '-Wp,-D_GLIBCXX_ASSERTIONS '
                      '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
-                     '-fstack-protector-strong '
-                     '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
-                     '-march=armv7-a -mfpu=vfpv3-d16 -mtune=generic-armv7-a '
-                     '-mabi=aapcs-linux -mfloat-abi=hard -D_GNU_SOURCE -fPIC '
-                     '-fwrapv -fno-semantic-interposition -flto '
+                     '-fstack-protector-strong   -march=armv7-a '
+                     '-mfpu=vfpv3-d16 -mtune=generic-armv7-a -mabi=aapcs-linux '
+                     '-mfloat-abi=hard -D_GNU_SOURCE -fPIC -fwrapv -flto '
                      '-fuse-linker-plugin -ffat-lto-objects '
                      '-flto-partition=none -g -std=c99 -Wextra '
                      '-Wno-unused-result -Wno-unused-parameter '
@@ -780,12 +783,11 @@ build_time_vars = {'ABIFLAGS': 'd',
                      '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                      '-Wp,-D_GLIBCXX_ASSERTIONS '
                      '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
-                     '-fstack-protector-strong '
-                     '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
-                     '-march=armv7-a -mfpu=vfpv3-d16 -mtune=generic-armv7-a '
-                     '-mabi=aapcs-linux -mfloat-abi=hard -D_GNU_SOURCE -fPIC '
-                     '-fwrapv -fno-semantic-interposition -O0 -Wno-cpp '
-                     '-I/builddir/build/BUILD/Python-3.9.2/Include/internal',
+                     '-fstack-protector-strong   -march=armv7-a '
+                     '-mfpu=vfpv3-d16 -mtune=generic-armv7-a -mabi=aapcs-linux '
+                     '-mfloat-abi=hard -D_GNU_SOURCE -fPIC -fwrapv -O0 '
+                     '-Wno-cpp '
+                     '-I/builddir/build/BUILD/Python-3.10.0/Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare '
                    '-DDYNAMIC_ANNOTATIONS_ENABLED=1  -O2  -fexceptions -g '
@@ -808,50 +810,44 @@ build_time_vars = {'ABIFLAGS': 'd',
                    '-pipe -Wall -Werror=format-security '
                    '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS '
                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
-                   '-fstack-protector-strong '
-                   '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
-                   '-march=armv7-a -mfpu=vfpv3-d16 -mtune=generic-armv7-a '
-                   '-mabi=aapcs-linux -mfloat-abi=hard -D_GNU_SOURCE -fPIC '
-                   '-fwrapv -fno-semantic-interposition -flto '
-                   '-fuse-linker-plugin -ffat-lto-objects -flto-partition=none '
-                   '-g -std=c99 -Wextra -Wno-unused-result '
-                   '-Wno-unused-parameter -Wno-missing-field-initializers '
+                   '-fstack-protector-strong   -march=armv7-a -mfpu=vfpv3-d16 '
+                   '-mtune=generic-armv7-a -mabi=aapcs-linux -mfloat-abi=hard '
+                   '-D_GNU_SOURCE -fPIC -fwrapv -flto -fuse-linker-plugin '
+                   '-ffat-lto-objects -flto-partition=none -g -std=c99 -Wextra '
+                   '-Wno-unused-result -Wno-unused-parameter '
+                   '-Wno-missing-field-initializers '
                    '-Werror=implicit-function-declaration -fvisibility=hidden '
                    '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
                    '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
                    '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS '
                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
-                   '-fstack-protector-strong '
-                   '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
-                   '-march=armv7-a -mfpu=vfpv3-d16 -mtune=generic-armv7-a '
-                   '-mabi=aapcs-linux -mfloat-abi=hard -D_GNU_SOURCE -fPIC '
-                   '-fwrapv -fno-semantic-interposition -O0 -Wno-cpp '
-                   '-I/builddir/build/BUILD/Python-3.9.2/Include/internal '
+                   '-fstack-protector-strong   -march=armv7-a -mfpu=vfpv3-d16 '
+                   '-mtune=generic-armv7-a -mabi=aapcs-linux -mfloat-abi=hard '
+                   '-D_GNU_SOURCE -fPIC -fwrapv -O0 -Wno-cpp '
+                   '-I/builddir/build/BUILD/Python-3.10.0/Include/internal '
                    '-IObjects -IInclude -IPython -I. '
-                   '-I/builddir/build/BUILD/Python-3.9.2/Include -fPIC '
+                   '-I/builddir/build/BUILD/Python-3.10.0/Include -fPIC '
                    '-DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now   -g  '
-                    '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now   -g '
+ 'PY_CORE_LDFLAGS': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now    -g  '
+                    '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now    -g '
                     '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now '
-                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld  '
-                    '-fno-semantic-interposition -g  -flto -fuse-linker-plugin '
-                    '-ffat-lto-objects -flto-partition=none -g -Wl,-z,relro '
-                    '-Wl,--as-needed  -Wl,-z,now '
-                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld  '
-                    '-fno-semantic-interposition -g',
+                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld   -g  -flto '
+                    '-fuse-linker-plugin -ffat-lto-objects '
+                    '-flto-partition=none -g -Wl,-z,relro -Wl,--as-needed  '
+                    '-Wl,-z,now '
+                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld   -g',
  'PY_CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-                '-I/builddir/build/BUILD/Python-3.9.2/Include',
+                '-I/builddir/build/BUILD/Python-3.10.0/Include',
+ 'PY_ENABLE_SHARED': 1,
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now   -g  -Wl,-z,relro '
-               '-Wl,--as-needed  -Wl,-z,now   -g',
+ 'PY_LDFLAGS': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now    -g  -Wl,-z,relro '
+               '-Wl,--as-needed  -Wl,-z,now    -g',
  'PY_LDFLAGS_NODIST': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now '
-                      '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld  '
-                      '-fno-semantic-interposition -g  -flto '
-                      '-fuse-linker-plugin -ffat-lto-objects '
+                      '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld   -g  '
+                      '-flto -fuse-linker-plugin -ffat-lto-objects '
                       '-flto-partition=none -g -Wl,-z,relro -Wl,--as-needed  '
                       '-Wl,-z,now '
-                      '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld  '
-                      '-fno-semantic-interposition -g',
+                      '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld   -g',
  'PY_SSL_DEFAULT_CIPHERS': 2,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare '
@@ -879,14 +875,12 @@ build_time_vars = {'ABIFLAGS': 'd',
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                         '-Wp,-D_GLIBCXX_ASSERTIONS '
                         '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
-                        '-fstack-protector-strong '
-                        '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
-                        '-march=armv7-a -mfpu=vfpv3-d16 -mtune=generic-armv7-a '
+                        '-fstack-protector-strong   -march=armv7-a '
+                        '-mfpu=vfpv3-d16 -mtune=generic-armv7-a '
                         '-mabi=aapcs-linux -mfloat-abi=hard -D_GNU_SOURCE '
-                        '-fPIC -fwrapv -fno-semantic-interposition -flto '
-                        '-fuse-linker-plugin -ffat-lto-objects '
-                        '-flto-partition=none -g -std=c99 -Wextra '
-                        '-Wno-unused-result -Wno-unused-parameter '
+                        '-fPIC -fwrapv -flto -fuse-linker-plugin '
+                        '-ffat-lto-objects -flto-partition=none -g -std=c99 '
+                        '-Wextra -Wno-unused-result -Wno-unused-parameter '
                         '-Wno-missing-field-initializers '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden -O2 -flto=auto -ffat-lto-objects '
@@ -894,15 +888,13 @@ build_time_vars = {'ABIFLAGS': 'd',
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                         '-Wp,-D_GLIBCXX_ASSERTIONS '
                         '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
-                        '-fstack-protector-strong '
-                        '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
-                        '-march=armv7-a -mfpu=vfpv3-d16 -mtune=generic-armv7-a '
+                        '-fstack-protector-strong   -march=armv7-a '
+                        '-mfpu=vfpv3-d16 -mtune=generic-armv7-a '
                         '-mabi=aapcs-linux -mfloat-abi=hard -D_GNU_SOURCE '
-                        '-fPIC -fwrapv -fno-semantic-interposition -O0 '
-                        '-Wno-cpp '
-                        '-I/builddir/build/BUILD/Python-3.9.2/Include/internal '
+                        '-fPIC -fwrapv -O0 -Wno-cpp '
+                        '-I/builddir/build/BUILD/Python-3.10.0/Include/internal '
                         '-IObjects -IInclude -IPython -I. '
-                        '-I/builddir/build/BUILD/Python-3.9.2/Include -fPIC',
+                        '-I/builddir/build/BUILD/Python-3.10.0/Include -fPIC',
  'Py_DEBUG': 1,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -911,14 +903,14 @@ build_time_vars = {'ABIFLAGS': 'd',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.9.2/build/debug',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.10.0/build/debug',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '@SGI_ABI@',
  'SHELL': '/bin/sh',
- 'SHLIBS': '-lcrypt -lpthread -ldl  -lutil -lm',
+ 'SHLIBS': '-lcrypt -ldl  -lm',
  'SHLIB_SUFFIX': '.so',
- 'SHM_NEEDS_LIBRT': 1,
+ 'SHM_NEEDS_LIBRT': 0,
  'SIGNED_RIGHT_SHIFT_ZERO_FILLS': 0,
  'SITEPATH': '',
  'SIZEOF_DOUBLE': 8,
@@ -939,9 +931,10 @@ build_time_vars = {'ABIFLAGS': 'd',
  'SIZEOF_VOID_P': 4,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SOABI': 'cpython-39d-arm-linux-gnueabihf',
- 'SRCDIRS': 'Parser Parser/pegen Objects Python Modules Modules/_io Programs',
- 'SRC_GDB_HOOKS': '/builddir/build/BUILD/Python-3.9.2/Tools/gdb/libpython.py',
+ 'SOABI': 'cpython-310d-arm-linux-gnueabihf',
+ 'SRCDIRS': 'Parser Objects Python Modules Modules/_io Programs',
+ 'SRC_GDB_HOOKS': '/builddir/build/BUILD/Python-3.10.0/Tools/gdb/libpython.py',
+ 'STATIC_LIBPYTHON': 0,
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
  'STRIPFLAG': '-s',
@@ -953,38 +946,41 @@ build_time_vars = {'ABIFLAGS': 'd',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.9.2/build/debug '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.10.0/build/debug '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.9.2/build/debug '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.10.0/build/debug '
                './python '
-               '/builddir/build/BUILD/Python-3.9.2/Tools/scripts/run_tests.py',
+               '/builddir/build/BUILD/Python-3.10.0/Tools/scripts/run_tests.py',
+ 'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
+ 'TEST_MODULES': 'yes',
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
  'TM_IN_SYS_TIME': 0,
  'TZPATH': '/usr/share/zoneinfo:/usr/lib/zoneinfo:/usr/share/lib/zoneinfo:/etc/zoneinfo',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
- 'UPDATE_FILE': 'python3.9 '
-                '/builddir/build/BUILD/Python-3.9.2/Tools/scripts/update_file.py',
+ 'UPDATE_FILE': '/builddir/build/BUILD/Python-3.10.0/Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 1,
- 'VERSION': '3.9',
- 'VPATH': '/builddir/build/BUILD/Python-3.9.2',
+ 'VERSION': '3.10',
+ 'VPATH': '/builddir/build/BUILD/Python-3.10.0',
+ 'WHEEL_PKG_DIR': '/usr/share/python-wheels',
  'WINDOW_HAS_FLAGS': 1,
  'WITH_DECIMAL_CONTEXTVAR': 1,
  'WITH_DOC_STRINGS': 1,
  'WITH_DTRACE': 1,
  'WITH_DYLD': 0,
+ 'WITH_EDITLINE': 0,
  'WITH_LIBINTL': 0,
  'WITH_NEXT_FRAMEWORK': 0,
  'WITH_PYMALLOC': 1,
  'WITH_VALGRIND': 1,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/builddir/build/BUILD/Python-3.9.2/build/debug',
- 'abs_srcdir': '/builddir/build/BUILD/Python-3.9.2',
+ 'abs_builddir': '/builddir/build/BUILD/Python-3.10.0/build/debug',
+ 'abs_srcdir': '/builddir/build/BUILD/Python-3.10.0',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
- 'srcdir': '/builddir/build/BUILD/Python-3.9.2'}
+ 'srcdir': '/builddir/build/BUILD/Python-3.10.0'}
